package com.chelvc.cloud.vehicle.client;


import java.util.List;

import com.chelvc.cloud.vehicle.client.dto.OmsOrderSettingDTO;
import com.chelvc.cloud.vehicle.client.param.OmsOrderSettingModifyParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 订单设置Service接口
 *
 * @author liude
 * @date 2023-11-08
 */
@FeignClient("vehicle")
interface OmsOrderSettingClient {
    /**
     * 查询订单设置
     *
     * @param id 订单设置主键
     * @return 订单设置
     */
    @GetMapping("/omsOrderSetting/selectOmsOrderSettingById")
    OmsOrderSettingDTO selectOmsOrderSettingById(@RequestParam("id") Long id);

    /**
     * 查询订单设置列表
     *
     * @param omsOrderSetting 订单设置
     * @return 订单设置集合
     */
    @GetMapping("/omsOrderSetting/selectOmsOrderSettingList")
    List<OmsOrderSettingDTO> selectOmsOrderSettingList(@SpringQueryMap OmsOrderSettingModifyParam omsOrderSetting);

    /**
     * 新增订单设置
     *
     * @param omsOrderSetting 订单设置
     * @return 结果
     */
    @PostMapping("/omsOrderSetting/insertOmsOrderSetting")
    int insertOmsOrderSetting(@RequestBody OmsOrderSettingModifyParam omsOrderSetting);

    /**
     * 修改订单设置
     *
     * @param omsOrderSetting 订单设置
     * @return 结果
     */
    @PostMapping("/omsOrderSetting/updateOmsOrderSetting")
    int updateOmsOrderSetting(@RequestBody OmsOrderSettingModifyParam omsOrderSetting);
}
