package com.chelvc.cloud.vehicle.server.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.chelvc.cloud.vehicle.client.dto.CouponDTO;
import com.chelvc.cloud.vehicle.client.param.CouponModifyParam;
import com.chelvc.cloud.vehicle.client.param.CouponPagingParam;
import com.chelvc.cloud.vehicle.server.entity.Coupon;
import com.chelvc.framework.common.model.Pagination;

import java.util.Collection;
import java.util.List;

/**
 * 优惠券业务操作接口
 *
 * @author Woody
 * @date 2023/7/17
 */
public interface CouponService extends IService<Coupon> {
    /**
     * 获取用户针对某个商品的可用优惠券
     *
     * @param userId         用户ID
     * @param goodsCouponIds 商品优惠券ID集合
     * @return 优惠券列表
     */
    List<CouponDTO> listUserGoodsActiveCoupons(Long userId, Collection<Long> goodsCouponIds);

    /**
     * 修改优惠券已领取数量
     *
     * @param couponId   优惠券ID
     * @param receiveNum 领取数量
     */
    void updateCouponReceivedNum(Long couponId, Integer receiveNum);

    /**
     * 新增优惠券
     *
     * @param param 新增参数
     * @return 优惠券主键
     */
    Long addCoupon(CouponModifyParam param);

    /**
     * 修改优惠券
     *
     * @param id    优惠券主键
     * @param param 修改参数
     */
    void updateCoupon(Long id, CouponModifyParam param);

    /**
     * 删除商品优惠券
     *
     * @param id    商品优惠券主键
     */
    void deleteCoupon(Long id);

    /**
     * 获取优惠券信息
     *
     * @param id 优惠券主键
     * @return 优惠券信息
     */
    CouponDTO getCoupon(Long id);

    /**
     * 查询优惠券信息
     *
     * @param param 查询参数
     * @return 优惠券分页信息
     */
    Pagination<CouponDTO> getCouponPaging(CouponPagingParam param);

    /**
     * 查询优惠券信息
     *
     * @param merchantId 商家ID
     * @param param 分页参数
     * @return 优惠券分页信息
     */
    Pagination<CouponDTO> getMerchantCouponPaging(Long merchantId, CouponPagingParam param);
}
