package com.chelvc.cloud.vehicle.server.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.chelvc.cloud.vehicle.client.dto.FavoriteDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.client.param.FavoritePagingParam;
import com.chelvc.cloud.vehicle.client.param.FavoriteQueryParam;
import com.chelvc.cloud.vehicle.server.entity.Favorite;
import com.chelvc.framework.common.model.Pagination;

import java.util.List;

/**
 * 用户收藏业务操作接口
 *
 * @author Woody
 * @date 2023/7/17
 */
public interface FavoriteService extends IService<Favorite> {

    /**
     * 收藏商家
     *
     * @param merchantId 商家ID
     * @return 收藏ID
     */
    Long addMerchantFavorite(Long merchantId,String type);

    /**
     * 取消我的收藏
     *
     * @param id 收藏ID
     */
    void deleteMineFavorite(Long id);

    /**
     * 查询收藏列表
     *
     * @param param 查询参数
     * @return 收藏店铺分页信息
     */
    Pagination<MerchantDTO> getFavoriteMerchantPaging(FavoritePagingParam param);

    /**
     * 查询用户收藏店铺列表
     *
     * @param param 查询参数
     * @return 用户收藏店铺列表
     */
    List<FavoriteDTO> listFavoriteMerchants(FavoriteQueryParam param);

    /**
     * 查询用户收藏商品列表
     * @return 用户收藏商品列表
     */
    List<FavoriteDTO> listFavoriteGoods();
}
