package com.chelvc.cloud.vehicle.server.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.client.dto.NoticeDTO;
import com.chelvc.cloud.vehicle.client.param.NoticeModifyParam;
import com.chelvc.cloud.vehicle.client.param.NoticePagingParam;
import com.chelvc.cloud.vehicle.server.copier.NoticeCopier;
import com.chelvc.cloud.vehicle.server.dao.NoticeMapper;
import com.chelvc.cloud.vehicle.server.entity.Notice;
import com.chelvc.cloud.vehicle.server.service.NoticeService;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.common.util.AssertUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.database.context.DatabaseContextHolder;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 通知配置业务操作实现
 *
 * @author liude
 * @date 2023/12/2
 */
@Service
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class NoticeServiceImpl extends ServiceImpl<NoticeMapper, Notice> implements NoticeService {
    @Override
    public Long addNotice(NoticeModifyParam param){
        Notice notice = NoticeCopier.INSTANCE.copying(param);
        Long userId = SessionContextHolder.getId();
        notice.setCreator(userId.toString());
        notice.setUpdater(userId.toString());
        notice.setStatus("1");
        this.save(notice);
        return notice.getId();
    }

    @Override
    public void updateNotice(@NonNull Long id, @NonNull NoticeModifyParam param) {
        Notice notice = AssertUtils.available(this.getById(id), "通知配置不存在");
        NoticeCopier.INSTANCE.copying(param, notice);
        this.updateById(notice);
    }

    @Override
    public Pagination<NoticeDTO> getNoticePaging(@NonNull NoticePagingParam param) {
        Page<Notice> page = this.lambdaQuery()
                .like(StringUtils.notEmpty(param.getTitle()), Notice::getTitle, param.getTitle())
                .orderByAsc(Notice::getStatus).page(DatabaseContextHolder.page(param.getPaging()));
        return DatabaseContextHolder.pagination(page, NoticeCopier.INSTANCE::copying);
    }

    @Override
    public List<NoticeDTO> getNoticeList(String type){
        List<Notice> notices = this.lambdaQuery()
                .eq(StringUtils.notEmpty(type),Notice::getSendObject,type)
                .eq(Notice::getStatus,1)
                .orderByAsc(Notice::getCreateTime)
                .list();
        return NoticeCopier.INSTANCE.copying(notices);
    }
}
